Conditionals
::::::::::::::::::::

.. toctree::
   :caption: Conditionals
   :maxdepth: 2

   intro-TurtlesandConditionals.rst
   BooleanValuesandBooleanExpressions.rst
   Logicaloperators.rst
   Theinandnotinoperators.rst
   PrecedenceofOperators.rst
   ConditionalExecutionBinarySelection.rst
   OmittingtheelseClauseUnarySelection.rst
   Nestedconditionals.rst
   Chainedconditionals.rst
   TheAccumulatorPatternwithConditionals.rst
   WPSettingUpConditionals.rst
   Glossary.rst
   Exercises.rst
   week3a1.rst
   